import { verifySession } from "@/app/_lib/dal";
import { getCollection, getDb } from "@/app/_lib/mongodb";
import { ObjectId } from "mongodb";
import { NextRequest } from "next/server";
import { ReactNode } from "react";
export type LinkType = {
    label: string;
    icon?: string;
    iconElement?: ReactNode;
    _id: string;
    href?: string;
    location?: string;

}
export async function GET(req: NextRequest) {
    try {
        const collection = await getCollection('link-type');
        // Check if the user is authenticated

        // 获取分页参数
        const page = parseInt(req.nextUrl.searchParams.get('page') || '1') || 1;
        const pageSize = parseInt(req.nextUrl.searchParams.get('pageSize') || '10') || 10;

        // 计算起始索引和结束索引
        const startIndex = (page - 1) * pageSize;

        // 查询数据
        const cursor = collection.find<LinkType>({}).skip(startIndex).limit(pageSize);
        const data = await cursor.toArray();

        // 计算总数量
        const total = await collection.countDocuments();

        return Response.json({
            total,
            list: data,
        })
    } catch (e) {
        return Response.error()
    }
}
export async function POST(req: NextRequest) {
    try {
        // 获取待插入的对象
        const link = await req.json()
        const collection = await getCollection('link-type')
        await collection.insertOne(link)
        return Response.json({ message: '成功' })
    } catch (e) {
        return Response.error()
    }
}

export async function PUT(req: NextRequest) {
    try {
        // 获取待更新的对象
        const link = await req.json() as LinkType
        const collection = await getCollection('link-type')
        await collection.replaceOne({ _id: new ObjectId(link._id) }, { ...link, _id: new ObjectId(link._id) })
        return Response.json({ message: '成功' })
    } catch (e) {
        console.log(e);

        return Response.error()
    }
}